Bundle class
Model class for ARB file.
Constructors
-
Bundle({DateTime? lastModified, String? locale, String? context, String? author, Set<
BundleItem> items = const {}}) -
Bundle.fromArb(Map<
String, dynamic> arb) -
factory
- Bundle.fromFile(File file)
-
factory
- Bundle.fromTsv(String tsv)
-
factory
Properties
-
arb
→ Map<
String, dynamic> -
Get ARB format Object.
no setter
-
final
- context → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ Set<
BundleItem> -
final
- lastModified → DateTime
-
final
- locale → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tsv → String
-
Get TSV string.
no setter
Methods
-
merge(
Bundle other) → Bundle -
Makes new Bundle which merged this with
other. Last modified time will update as now. Items that not in this but other are append. Rest of all are same as this. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited